12.8 - 2.01% speedometer3 NewsSite-Nuxt/NavigateToUS/Sync / speedometer3 NewsSite-Nuxt/total + 21 more (Linux, OSX, Windows) regression on Mon July 22 2024
Categories
(Testing :: Raptor, defect)
Tracking
(firefox-esr115 unaffected, firefox-esr128 unaffected, firefox128 unaffected, firefox129 unaffected, firefox130 affected)
| Tracking | Status | |
|---|---|---|
| firefox-esr115 | --- | unaffected |
| firefox-esr128 | --- | unaffected |
| firefox128 | --- | unaffected |
| firefox129 | --- | unaffected |
| firefox130 | --- | affected |
People
(Reporter: fbilt, Unassigned)
References
(Regression)
Details
(Keywords: perf, perf-alert, regression)
Perfherder has detected a browsertime performance change from push bebaa09716b033fea32fdbc1223ac5c05a42c5ad.
Regressions:
| Ratio | Test | Platform | Options | Absolute values (old vs new) | Performance Profiles |
|---|---|---|---|---|---|
| 13% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | linux1804-64-nightlyasrelease-qr | fission webrender | 33.35 -> 37.62 | Before/After |
| 12% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | linux1804-64-shippable-qr | fission webrender | 32.41 -> 36.24 | Before/After |
| 8% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | macosx1015-64-shippable-qr | fission webrender | 30.18 -> 32.60 | Before/After |
| 7% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | macosx1015-64-nightlyasrelease-qr | fission webrender | 31.32 -> 33.66 | Before/After |
| 7% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | windows11-64-shippable-qr | fission webrender | 18.17 -> 19.53 | Before/After |
| 7% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | windows11-64-nightlyasrelease-qr | fission webrender | 17.89 -> 19.20 | Before/After |
| 7% | speedometer3 NewsSite-Nuxt/NavigateToUS/Sync | macosx1015-64-nightlyasrelease-qr | fission webrender | 31.10 -> 33.33 | Before/After |
| 6% | speedometer3 NewsSite-Nuxt/NavigateToUS/total | linux1804-64-nightlyasrelease-qr | fission webrender | 77.77 -> 82.72 | Before/After |
| 6% | speedometer3 Charts-observable-plot/Dotted/Async | linux1804-64-shippable-qr | fission webrender | 8.02 -> 8.48 | Before/After |
| 6% | speedometer3 NewsSite-Nuxt/NavigateToUS/total | linux1804-64-shippable-qr | fission webrender | 76.28 -> 80.48 | Before/After |
| ... | ... | ... | ... | ... | ... |
| 3% | speedometer3 NewsSite-Nuxt/NavigateToUS/total | windows11-64-nightlyasrelease-qr | fission webrender | 38.58 -> 39.89 | Before/After |
| 3% | speedometer3 NewsSite-Nuxt/total | linux1804-64-nightlyasrelease-qr | fission webrender | 219.50 -> 225.85 | Before/After |
| 2% | speedometer3 NewsSite-Nuxt/total | windows11-64-shippable-qr | fission webrender | 106.83 -> 109.08 | Before/After |
| 2% | speedometer3 NewsSite-Nuxt/total | macosx1015-64-shippable-qr | fission webrender | 183.32 -> 187.16 | Before/After |
| 2% | speedometer3 NewsSite-Nuxt/total | macosx1015-64-nightlyasrelease-qr | fission webrender | 188.26 -> 192.05 | Before/After |
Improvements:
| Ratio | Test | Platform | Options | Absolute values (old vs new) | Performance Profiles |
|---|---|---|---|---|---|
| 4% | speedometer3 TodoMVC-jQuery/CompletingAllItems/Async | windows11-64-nightlyasrelease-qr | fission webrender | 2.04 -> 1.95 | Before/After |
| 4% | speedometer3 TodoMVC-JavaScript-ES5/CompletingAllItems/Async | linux1804-64-shippable-qr | fission webrender | 2.89 -> 2.77 | Before/After |
| 3% | speedometer3 TodoMVC-JavaScript-ES5/CompletingAllItems/Async | linux1804-64-nightlyasrelease-qr | fission webrender | 2.92 -> 2.83 | Before/After |
| 3% | speedometer3 TodoMVC-React-Complex-DOM/CompletingAllItems/Async | linux1804-64-shippable-qr | fission webrender | 6.03 -> 5.83 | Before/After |
| 3% | speedometer3 TodoMVC-JavaScript-ES6-Webpack-Complex-DOM/CompletingAllItems/Async | windows11-64-nightlyasrelease-qr | fission webrender | 3.88 -> 3.77 | Before/After |
| ... | ... | ... | ... | ... | ... |
| 2% | speedometer3 NewsSite-Next/NavigateToWorld/total | macosx1400-64-shippable-qr | fission webrender | 18.25 -> 17.86 | Before/After |
As author of one of the patches included in that push, we need your help to address this regression.
Details of the alert can be found in the alert summary, including links to graphs and comparisons for each of the affected tests. Please follow our guide to handling regression bugs and let us know your plans within 3 business days, or the patch(es) may be backed out in accordance with our regression policy.
If you need the profiling jobs you can trigger them yourself from treeherder job view or ask a sheriff to do that for you.
You can run these tests on try with ./mach try perf --alert 1463
For more information on performance sheriffing please see our FAQ.
Comment 1•2 years ago
|
||
Set release status flags based on info from the regressing bug 1867135
Comment 2•2 years ago
|
||
Based on the retriggers I made on the graph before the culprit revision, it doesn't seem like this is an infra. It's weird that the changes would have caused these performance changes, considering this is just a patch to use the in-tree resources instead of cloning the speedometer repo before running the test. Also, running mach try perf did not report any performance changes on try. I'm proposing we close the defect as WONTFIX and add the "harness" tag to the summary. What do you think sparky ?
Comment 3•2 years ago
•
|
||
I think what happened here is that we updated the speedometer3 code that the PGO stage is using and this caused some changes from there. I agree with closing this as WONTFIX but I'll mention this to the sp3 team so they're aware of it. I'm talking about the installer size change here: https://bugzilla.mozilla.org/show_bug.cgi?id=1867135#c5
Regarding the changes in this bug, I agree it's definitely a harness change.
Comment 4•2 years ago
|
||
(In reply to Greg Mierzwinski [:sparky] from comment #3)
I think what happened here is that we updated the speedometer3 code that the PGO stage is using and this caused some changes from there. I agree with closing this as WONTFIX but I'll mention this to the sp3 team so they're aware of it. I'm talking about the installer size change here: https://bugzilla.mozilla.org/show_bug.cgi?id=1867135#c5
Regarding the changes in this bug, I agree it's definitely a harness change.
Thanks for replying sparky, closing the defect as WONTFIX.
Description
•